package com.aucma.report.service;

import java.util.List;
import com.aucma.report.domain.BasePdaRecord;

/**
 * PDA管理Service接口
 * 
 * @author Yinq
 * @date 2023-11-21
 */
public interface IBasePdaRecordService 
{
    /**
     * 查询PDA管理
     * 
     * @param objId PDA管理主键
     * @return PDA管理
     */
    public BasePdaRecord selectBasePdaRecordByObjId(Long objId);

    /**
     * 查询PDA管理列表
     * 
     * @param basePdaRecord PDA管理
     * @return PDA管理集合
     */
    public List<BasePdaRecord> selectBasePdaRecordList(BasePdaRecord basePdaRecord);

    /**
     * 新增PDA管理
     * 
     * @param basePdaRecord PDA管理
     * @return 结果
     */
    public int insertBasePdaRecord(BasePdaRecord basePdaRecord);

    /**
     * 修改PDA管理
     * 
     * @param basePdaRecord PDA管理
     * @return 结果
     */
    public int updateBasePdaRecord(BasePdaRecord basePdaRecord);

    /**
     * 批量删除PDA管理
     * 
     * @param objIds 需要删除的PDA管理主键集合
     * @return 结果
     */
    public int deleteBasePdaRecordByObjIds(Long[] objIds);

    /**
     * 删除PDA管理信息
     * 
     * @param objId PDA管理主键
     * @return 结果
     */
    public int deleteBasePdaRecordByObjId(Long objId);
}
